import { Message } from "./message.model";
import { Observable } from "rxjs/internal/Observable";
import * as i0 from "@angular/core";
export declare class MessageService {
    private messages;
    private messageSource;
    private msgTypePattern;
    private msgStore;
    private langu;
    constructor();
    getObservable(): Observable<Message[]>;
    /**
     * Tell the message service what is the message storage(array) and language
     * msgStore: an Array that stores all messages in a session
     * {string} the language preferred in the session
     */
    setMessageStore(msgStore: any, langu: string): void;
    /**
     * Add a message object into a message list
     * {Message} message
     */
    add(message: Message): void;
    /**
     * Report only one message at a time
     */
    report(message: Message): void;
    /**
     * Report a message at a time based on msgCat, msgName, msgType
     * It is usually used for messages generated in client side(Angular)
     * msgCat
     * msgName
     * msgType
     * {string} args
     */
    reportMessage(msgCat: any, msgName: any, msgType: any, ...args: string[]): void;
    /**
     * Add a message to a list based on msgCat, msgName, msgType
     * It is usually used for messages generated in client side(Angular)
     * msgCat
     * msgName
     * msgType
     * {string} args
     */
    addMessage(msgCat: any, msgName: any, msgType: any, ...args: string[]): void;
    /**
     * Clear all the messages in the container(show in the UI)
     */
    clearMessages(): void;
    /**
     * Remove a message from the list by its index(position)
     * idx
     */
    removeMessage(idx: any): void;
    /**
     * Generate a message object based on msgCat, msgName, msgType from the message store array
     * The message store array is generated in client side.
     * It supports variable parameters for the placeholders' replacement in short and long texts.
     */
    generateMessage(msgCat: any, msgName: any, msgType: any, ...args: string[]): Message;
    private checkInputParameters;
    private replacePlaceholdersInShortText;
    private replacePlaceholdersInLongText;
    static ɵfac: i0.ɵɵFactoryDeclaration<MessageService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MessageService>;
}
//# sourceMappingURL=message.service.d.ts.map